@@ -2,7 +2,7 @@ package Mojolicious::Plugin::RevealJS;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 $VERSION = eval $VERSION;
 
 use Mojo::Home;
@@ -23,10 +23,13 @@ sub register {
   push @{ $app->static->paths },   $home->rel_dir('public');
   push @{ $app->renderer->paths }, $home->rel_dir('templates');
 
-  #$conf->{layout} = 'revealjs' unless exists $conf->{layout};
-  #if (defined(my $layout = $conf->{layout})) {
-    #$app->defaults(layout => $layout);
-  #}
+  $app->defaults('revealjs.init' => {
+    controls => \1,
+    progress => \1,
+    history  => \1,
+    center   => \1,
+    transition => 'slide', #none/fade/slide/convex/concave/zoom
+  });
 
   $app->helper('include_code' => \&_include_code);
   $app->helper('revealjs.export' => \&_export);
@@ -80,7 +83,7 @@ Mojolicious::Plugin::RevealJS - Mojolicious ❤️ Reveal.js
 
 L<Mojolicious::Plugin::RevealJS> is yet another attempt at making presentations with L<Mojolicious>.
 While the author's previous attempts have tried do too much, this one simply makes it easier to use L<Reveal.js|http://lab.hakim.se/reveal-js>.
-It provides a layout (C<revealjs>) which contains the boilderplate and loads the bundled libraries.
+It provides a layout (C<revealjs>) which contains the boilerplate and loads the bundled libraries.
 It also provides a few simple helpers.
 Future versions of the plugin will allow setting of configuration like themes.
 
@@ -103,7 +106,95 @@ The author makes no compatibilty promises.
 This layout is essentially the standard template distributed as part of the Reveal.js tarball.
 It is modified for use in a Mojolicious template.
 
-It accepts the stash parameters C<title>, C<author> and C<description> which set the header (metadata) values you would expect.
+=head3 stash paramters
+
+It accepts the stash parameters:
+
+=over
+
+=item *
+
+author - sets the metadata value
+
+=item *
+
+description - sets the metadata value
+
+=item *
+
+init - Reveal.js initialization options, a hashref for JSON conversion documented below
+
+=item *
+
+theme - a string representing a theme css to be included.
+If the string ends in C<.css> it is included literally, otherwise it is assumed to be the name of a bundled Reveal.js theme.
+Bundled themes are: black, white, league, beige, sky, night, serif, simple, solarized.
+Defaults to black.
+See more on the L<"Reveal.js page"|https://github.com/hakimel/reveal.js#theming>.
+
+=item *
+
+title - sets the window title, not used on the title slide
+
+=back
+
+=head3 initialization parameters
+
+As mentioned above, the stash key C<init> is a hashref that is merge into a set of defaults and used to initialize Reveal.js.
+Some RevealJS initialization options, specifically those that have a default are:
+
+=over
+
+=item *
+
+center - enable slide centering (boolean, true by default)
+
+=item *
+
+controls - enable controls (boolean, true by default)
+
+=item *
+
+history - enable history (boolean, true by default)
+
+=item *
+
+progress - enable progress indicator (boolean, true by default)
+
+=item *
+
+transition - set the slide transition type (one of: none, fade, slide, convex, concave, zoom; default: slide)
+
+=back
+
+These defaults are set in the default stash value for C<revealjs.init>.
+So they can be modified globally modifying that value (probably during setup).
+
+  $app->defaults->{'revealjs.init'}{transition} = 'none';
+
+Note that booleans are references to scalar values, C<true == \1>, C<false == \0>.
+See more availalbe options on the L<"Reveal.js page"|https://github.com/hakimel/reveal.js#configuration>.
+
+=head3 additional templates
+
+In order to further customize the template the following unimplemented templates are included into the layout
+
+=over
+
+=item *
+
+C<revealjs_head.html.ep> - included at the end of the C<< <head> >> tag.
+
+=item *
+
+C<revealjs_preinit.js.ep> - included just before initializing Reveal.js.
+Especially useful to modify the javascript variable C<init>.
+
+=item *
+
+C<revealjs_body.html.ep> - included at the end of the C<< <body> >> tag.
+
+=back
 
 =head1 HELPERS
 
